"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = run;
const core = __importStar(require("@actions/core"));
const child_process_1 = require("child_process");
async function run() {
    try {
        const inputs = readInputs();
        core.info("🔑 Logging into Bitwarden CLI...");
        const sessionKey = loginToBitwarden(inputs.password, inputs.server);
        core.info("✅ Successfully logged in!");
        core.info("🔍 Retrieving secrets...");
        const parsedSecrets = retrieveSecrets(inputs.secrets, sessionKey);
        core.info("📄 Generating shell export statements...");
        generateShellExports(parsedSecrets);
        core.info("✅ Successfully retrieved and set secrets!");
    }
    catch (error) {
        core.setFailed(`❌ Error: ${error instanceof Error ? error.message : error}`);
    }
}
function readInputs() {
    const password = core.getInput("password", { required: true });
    const server = core.getInput("server", { required: true });
    const secretsRaw = core.getInput("secrets", { required: true });
    const secrets = secretsRaw
        .split("\n")
        .map((s) => s.trim())
        .filter((s) => s.includes(">"));
    if (secrets.length === 0) {
        throw new Error("No valid secrets provided.");
    }
    return { password, server, secrets };
}
function loginToBitwarden(password, server) {
    const output = (0, child_process_1.execSync)(`BW_SERVER=${server} bw login --raw`, {
        input: password + "\n",
        encoding: "utf-8",
    }).trim();
    return output;
}
function retrieveSecrets(secrets, sessionKey) {
    const parsedSecrets = {};
    secrets.forEach((secretLine) => {
        const [id, name] = secretLine.split(">").map((s) => s.trim());
        try {
            const value = (0, child_process_1.execSync)(`BW_SESSION=${sessionKey} bw get secret ${id}`, {
                encoding: "utf-8",
            }).trim();
            parsedSecrets[name] = value;
        }
        catch {
            core.warning(`⚠️ Could not retrieve secret for ID: ${id}`);
        }
    });
    return parsedSecrets;
}
function generateShellExports(secrets) {
    let exportCommands = "";
    for (const [key, value] of Object.entries(secrets)) {
        exportCommands += `export ${key}="${value}"\n`;
        core.setSecret(value);
    }
    console.log(exportCommands);
}
run();
